@@ -7,7 +7,7 @@ CREDENTIALS_PATH = '../../../Secrets/YouTube'
 def test_get_metadata_01():
     easy_wrapper = YoutubeEasyWrapper()
     easy_wrapper.initialize(credentials_path=CREDENTIALS_PATH)
-    metadata = easy_wrapper.get_metadata(video_id='rfscVS0vtbw')
+    metadata = easy_wrapper.get_metadata(video_id='f3lUEnMaiAU')
     print(metadata['comments'][0])
 
 
@@ -34,4 +34,3 @@ def test_search_videos_02():
     results = easy_wrapper.search_videos(search_keyword='python', order='relevance')
     order_id = 1
     print(results[order_id]['video_id'])
-
